@@ -1,3 +1,4 @@
+import os
 import socket
 import time
 
@@ -49,12 +50,12 @@ class ResultHandlerMqtt:
     def on_connect(self, client, userdata, flags, rc):
         print('connected')
         self.connected = True
-        self.disconnected_data = self.load_data("local_results.txt")
+        self.disconnected_data = self.load_data(constants.LOCAL_RESULTS_PATH)
 
         if len(self.disconnected_data) > 0:
             self.publish_historic_data(self.disconnected_data)
             self.disconnected_data = []
-            self.clear_file("local_results.txt")
+            self.clear_file(constants.LOCAL_RESULTS_PATH)
 
     def clear_file(self, filename):
         open(filename, 'w').close()
@@ -87,7 +88,7 @@ class ResultHandlerMqtt:
             elif data_type == 'attribute':
                 self.send_attribute(device, results)
         else:
-            self.store_local(results, "local_results.txt", device)
+            self.store_local(results, constants.LOCAL_RESULTS_PATH, device)
 
     def store_local(self, results, filename, device):
         file = open(filename, 'a')
@@ -124,6 +125,7 @@ class ResultHandlerMqtt:
                     # add json object to list
                     result_list.append(json_object)
         except:
+            os.mkdir(constants.LOCAL_RESULTS_DIR)
             f = open(filename, 'w+')
         return result_list
 
