@@ -30,3 +30,5 @@ RESULT_KEY_DATA = "data"
 RESULT_KEY_DEBUG = "debug"
 
 EXTRA_DATA_KEY_RESULTS = "results"
+LOCAL_RESULTS_DIR = "C:/temp/ndu"
+LOCAL_RESULTS_PATH = "C:/temp/ndu/local_results.txt"
